@@ -14,10 +14,6 @@
 # limitations under the License.
 """Provides common arguments for the Spanner command surface."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 from argcomplete.completers import FilesCompleter
 from cloudsdk.google.protobuf import descriptor_pb2
 from googlecloudsdk.api_lib.spanner import databases
@@ -293,6 +289,40 @@ def Nodes(required=False, text='Number of nodes for the instance.'):
   )
 
 
+def AddTags(parser):
+  """Makes the base.Argument for --tags flag."""
+  help_parts = [
+      'List of tags KEY=VALUE pairs to bind.',
+      'Each item must be expressed as either',
+      'ID: `<tag-key-id>=<tag-value-id>` or\n',
+      'Namespaced name: `<tag-key-namespaced-name>=<tag-value-short-name>`.\n',
+      'Example: `tagKeys/123=tagValues/223`\n',
+      'Example: `123/environment=production,123/costCenter=marketing`\n',
+  ]
+  parser.add_argument(
+      '--tags',
+      metavar='KEY=VALUE',
+      type=arg_parsers.ArgDict(),
+      action=arg_parsers.UpdateAction,
+      hidden=True,
+      help='\n'.join(help_parts),
+  )
+
+
+def GetTagsFromArgs(args, tags_message, tags_arg_name='tags'):
+  """Makes the tags message object."""
+  tags = getattr(args, tags_arg_name, None)
+  if not tags:
+    return None
+  # Sorted for test stability
+  return tags_message(
+      additionalProperties=[
+          tags_message.AdditionalProperty(key=key, value=value)
+          for key, value in sorted(tags.items())
+      ]
+  )
+
+
 def ProcessingUnits(
     required=False, text='Number of processing units for the instance.'
 ):
@@ -337,10 +367,11 @@ def AutoscalingMinProcessingUnits(required=False):
   )
 
 
-def AutoscalingHighPriorityCpuTarget(required=False):
+def AutoscalingHighPriorityCpuTarget(required=False, hidden=False):
   return base.Argument(
       '--autoscaling-high-priority-cpu-target',
       required=required,
+      hidden=hidden,
       type=int,
       help=(
           'Specifies the target percentage of high-priority CPU the autoscaled'
@@ -349,6 +380,19 @@ def AutoscalingHighPriorityCpuTarget(required=False):
   )
 
 
+def AutoscalingTotalCpuTarget(required=False, hidden=True):
+  return base.Argument(
+      '--autoscaling-total-cpu-target',
+      required=required,
+      hidden=hidden,
+      type=int,
+      help=(
+          'Specifies the target percentage of total CPU the autoscaled instance'
+          ' can utilize.'
+      ),
+  )
+
+
 def AutoscalingStorageTarget(required=False):
   return base.Argument(
       '--autoscaling-storage-target',
@@ -361,21 +405,73 @@ def AutoscalingStorageTarget(required=False):
   )
 
 
-def AsymmetricAutoscalingOptionFlag():
-  help_text = (
-      'Specify the asymmetric autoscaling option for the instance. '
+def DisableHighPriorityCpuAutoscaling(required=False, hidden=True):
+  return base.Argument(
+      '--disable-high-priority-cpu-autoscaling',
+      required=required,
+      hidden=hidden,
+      type=bool,
+      help=(
+          'Set the flag to disable high priority CPU autoscaling on the '
+          'replica.'
+      ),
   )
+
+
+def DisableTotalCpuAutoscaling(required=False, hidden=True):
+  return base.Argument(
+      '--disable-total-cpu-autoscaling',
+      required=required,
+      hidden=hidden,
+      type=bool,
+      help='Set the flag to disable total CPU autoscaling on the replica.',
+  )
+
+
+def DisableDownScaling(required=False, hidden=True):
+  return base.Argument(
+      '--disable-downscaling',
+      required=required,
+      hidden=hidden,
+      action=arg_parsers.StoreTrueFalseAction,
+      help='Set the flag to disable downscaling for the autoscaled instance.',
+  )
+
+
+def AsymmetricAutoscalingOptionFlag(
+    include_total_cpu_target=False, include_disable_autoscaling_args=False
+):
+  """Adds the --asymmetric-autoscaling-option flag.
+
+  Args:
+    include_total_cpu_target: bool. If True, include 'total_cpu_target' in the
+      ArgDict spec.
+    include_disable_autoscaling_args: bool. If True, include
+      'disable_high_priority_cpu_autoscaling' and
+      'disable_total_cpu_autoscaling' in the ArgDict spec.
+
+  Returns:
+    A base.Argument for the --asymmetric-autoscaling-option flag.
+  """
+  help_text = 'Specifies the asymmetric autoscaling option for the instance. '
+  spec = {
+            'location': str,
+            'min_nodes': int,
+            'max_nodes': int,
+            'min_processing_units': int,
+            'max_processing_units': int,
+            'high_priority_cpu_target': int,
+  }
+  if include_total_cpu_target:
+    spec['total_cpu_target'] = int
+  if include_disable_autoscaling_args:
+    spec['disable_high_priority_cpu_autoscaling'] = arg_parsers.ArgBoolean()
+    spec['disable_total_cpu_autoscaling'] = arg_parsers.ArgBoolean()
+
   return base.Argument(
       '--asymmetric-autoscaling-option',
       type=arg_parsers.ArgDict(
-          spec={
-              'location': str,
-              'min_nodes': int,
-              'max_nodes': int,
-              'min_processing_units': int,
-              'max_processing_units': int,
-              'high_priority_cpu_target': int,
-          },
+          spec=spec,
           required_keys=['location'],
       ),
       required=False,
@@ -485,6 +581,10 @@ def AddCapacityArgsForInstance(
     parser,
     add_asymmetric_option_flag=False,
     asymmetric_options_group=False,
+    autoscaling_cpu_target_group=False,
+    add_asymmetric_total_cpu_target_flag=False,
+    add_asymmetric_disable_autoscaling_flags=False,
+    add_disable_downscaling_flag=False,
 ):
   """Parse the instance capacity arguments, including manual and autoscaling.
 
@@ -496,6 +596,14 @@ def AddCapacityArgsForInstance(
       option flag.
     asymmetric_options_group: bool. If True, add the asymmetric autoscaling
       options group.
+    autoscaling_cpu_target_group: bool. If True, add the autoscaling cpu target
+      group.
+    add_asymmetric_total_cpu_target_flag: bool. If True, add the asymmetric
+      total cpu target flag.
+    add_asymmetric_disable_autoscaling_flags: bool. If True, add the asymmetric
+      disable autoscaling flags.
+    add_disable_downscaling_flag: bool. If True, add the disable downscaling
+      flag.
   """
   capacity_parser = parser.add_argument_group(mutex=True, required=False)
 
@@ -507,12 +615,35 @@ def AddCapacityArgsForInstance(
   autoscaling_config_group_parser = capacity_parser.add_argument_group(
       help='Autoscaling'
   )
-  AutoscalingHighPriorityCpuTarget(
+  if autoscaling_cpu_target_group:
+    # TODO(b/424254143): Add help text for the cpu target options group "Specify
+    # both or only one of the CPU targets:"
+    cpu_target_options_group_parser = (
+        autoscaling_config_group_parser.add_argument_group(
+            required=require_all_autoscaling_args,
+            help='',
+        )
+    )
+    AutoscalingHighPriorityCpuTarget(
+        required=False
+    ).AddToParser(cpu_target_options_group_parser)
+    AutoscalingTotalCpuTarget(
+        required=False, hidden=True
+    ).AddToParser(cpu_target_options_group_parser)
+  else:
+    AutoscalingHighPriorityCpuTarget(
+        required=require_all_autoscaling_args
+    ).AddToParser(autoscaling_config_group_parser)
+
+  if add_disable_downscaling_flag:
+    DisableDownScaling(
+        required=False, hidden=True
+    ).AddToParser(autoscaling_config_group_parser)
+
+  AutoscalingStorageTarget(
       required=require_all_autoscaling_args
-  ).AddToParser(autoscaling_config_group_parser)
-  AutoscalingStorageTarget(required=require_all_autoscaling_args).AddToParser(
-      autoscaling_config_group_parser
-  )
+    ).AddToParser(autoscaling_config_group_parser)
+
   autoscaling_limits_group_parser = autoscaling_config_group_parser.add_argument_group(
       mutex=True,
       required=require_all_autoscaling_args,
@@ -552,23 +683,39 @@ def AddCapacityArgsForInstance(
               mutex=True
           )
       )
-      AsymmetricAutoscalingOptionFlag().AddToParser(
-          asymmetric_options_group_parser
-      )
+      AsymmetricAutoscalingOptionFlag(
+          add_asymmetric_total_cpu_target_flag,
+          add_asymmetric_disable_autoscaling_flags
+      ).AddToParser(asymmetric_options_group_parser)
       ClearAsymmetricAutoscalingOptionsFlag().AddToParser(
           asymmetric_options_group_parser
       )
     else:
-      AsymmetricAutoscalingOptionFlag().AddToParser(
-          autoscaling_config_group_parser
-      )
+      AsymmetricAutoscalingOptionFlag(
+          include_total_cpu_target=add_asymmetric_total_cpu_target_flag,
+          include_disable_autoscaling_args=add_asymmetric_disable_autoscaling_flags,
+      ).AddToParser(parser=autoscaling_config_group_parser)
 
 
-def AddCapacityArgsForInstancePartition(parser):
+def AddCapacityArgsForInstancePartition(
+    parser,
+    add_autoscaling_args=True,
+    autoscaling_args_hidden=False,
+    require_all_autoscaling_args=True,
+):
   """Parse the instance partition capacity arguments.
 
   Args:
     parser: the argparse parser for the command.
+    add_autoscaling_args: bool. If True, add the autoscaling arguments. This is
+      required because these arguments are only available in the ALPHA track.
+      This will be removed once the arguments are promoted to BETA and GA.
+    autoscaling_args_hidden: bool. If True, mark the autoscaling arguments as
+      hidden. This will be removed once the arguments are promoted to BETA and
+      GA.
+    require_all_autoscaling_args: bool. If True, a complete autoscaling config
+      is required. This is required during instance partition creation, but not
+      during instance partition update.
   """
   capacity_parser = parser.add_argument_group(mutex=True, required=False)
 
@@ -580,6 +727,64 @@ def AddCapacityArgsForInstancePartition(parser):
       text='Number of processing units for the instance partition.'
   ).AddToParser(capacity_parser)
 
+  # TODO(b/434234543): Remove this check once the autoscaling arguments are
+  # promoted to BETA and GA.
+  if not add_autoscaling_args:
+    return
+
+  # Autoscaling.
+  autoscaling_config_group_parser = capacity_parser.add_argument_group(
+      help='Autoscaling',
+      hidden=autoscaling_args_hidden,
+  )
+  cpu_target_options_group_parser = (
+      autoscaling_config_group_parser.add_argument_group(
+          required=require_all_autoscaling_args,
+          help='Target for high priority CPU utilization.',
+      )
+  )
+  AutoscalingHighPriorityCpuTarget(
+      required=False,
+      hidden=autoscaling_args_hidden,
+  ).AddToParser(cpu_target_options_group_parser)
+  AutoscalingTotalCpuTarget(
+      required=False,
+      hidden=autoscaling_args_hidden,
+  ).AddToParser(cpu_target_options_group_parser)
+  AutoscalingStorageTarget(required=require_all_autoscaling_args).AddToParser(
+      autoscaling_config_group_parser
+  )
+  autoscaling_limits_group_parser = autoscaling_config_group_parser.add_argument_group(
+      mutex=True,
+      required=require_all_autoscaling_args,
+      help=(
+          'Autoscaling limits can be defined in either nodes or processing'
+          ' units.'
+      ),
+  )
+  autoscaling_node_limits_group_parser = (
+      autoscaling_limits_group_parser.add_argument_group(
+          help='Autoscaling limits in nodes:'
+      )
+  )
+  AutoscalingMinNodes(required=require_all_autoscaling_args).AddToParser(
+      autoscaling_node_limits_group_parser
+  )
+  AutoscalingMaxNodes(required=require_all_autoscaling_args).AddToParser(
+      autoscaling_node_limits_group_parser
+  )
+  autoscaling_pu_limits_group_parser = (
+      autoscaling_limits_group_parser.add_argument_group(
+          help='Autoscaling limits in processing units:'
+      )
+  )
+  AutoscalingMinProcessingUnits(
+      required=require_all_autoscaling_args
+  ).AddToParser(autoscaling_pu_limits_group_parser)
+  AutoscalingMaxProcessingUnits(
+      required=require_all_autoscaling_args
+  ).AddToParser(autoscaling_pu_limits_group_parser)
+
 
 def TargetConfig(required=True):
   return base.Argument(
@@ -1079,7 +1284,7 @@ def SourceUri(req, text='URI of the file with data to import'):
 
 
 def SourceFormat(req, text='Format of the file with data to import.'
-                 'Supported formats: csv or myssqldump or pgdump'):
+                 'Supported formats: csv or mysqldump or pgdump'):
   return base.Argument(
       '--source-format', required=req, help=text)
 
