@@ -413,7 +413,9 @@ class Update(base.UpdateCommand):
     flags.AddEnableMultiNetworkingFlag(group)
     flags.AddContainerdConfigFlag(group)
     flags.AddAutoprovisioningResourceManagerTagsUpdate(group)
-    flags.AddFleetProjectFlag(group, is_update=True)
+    group_fleet_flags = group.add_group()
+    flags.AddFleetProjectFlag(group_fleet_flags, is_update=True)
+    flags.AddMembershipTypeFlags(group_fleet_flags, is_update=True)
     flags.AddInTransitEncryptionFlag(group)
     flags.AddEnableCiliumClusterwideNetworkPolicyFlag(group, is_update=True)
     flags.AddEnableFqdnNetworkPolicyFlag(group)
@@ -454,6 +456,10 @@ class Update(base.UpdateCommand):
     flags.AddEnableDefaultComputeClassFlag(group)
     flags.AddNetworkTierFlag(group)
     flags.AddControlPlaneEgressFlag(group)
+    flags.AddAutopilotPrivilegedAdmissionFlag(group, hidden=True)
+    flags.AddEnableKernelModuleSignatureEnforcementFlag(
+        group, for_node_pool=False, hidden=True
+    )
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -556,6 +562,8 @@ class Update(base.UpdateCommand):
     opts.fleet_project = args.fleet_project
     opts.enable_fleet = args.enable_fleet
     opts.clear_fleet_project = args.clear_fleet_project
+    opts.membership_type = args.membership_type
+    opts.unset_membership_type = args.unset_membership_type
     opts.enable_cilium_clusterwide_network_policy = (
         args.enable_cilium_clusterwide_network_policy
     )
@@ -612,6 +620,13 @@ class Update(base.UpdateCommand):
     opts.enable_default_compute_class = args.enable_default_compute_class
     opts.network_tier = args.network_tier
     opts.control_plane_egress_mode = args.control_plane_egress
+    opts.autopilot_privileged_admission = (
+        args.autopilot_privileged_admission
+    )
+    opts.enable_pod_snapshots = getattr(args, 'pod_snapshots_enabled', None)
+    opts.enable_kernel_module_signature_enforcement = (
+        args.enable_kernel_module_signature_enforcement
+    )
     return opts
 
   def Run(self, args):
@@ -1009,6 +1024,17 @@ to completion."""
         )
       except apitools_exceptions.HttpError as error:
         raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
+    elif (
+        getattr(args, 'enable_kernel_module_signature_enforcement', None)
+        is not None
+    ):
+      try:
+        op_ref = adapter.ModifyKernelModuleSignatureEnforcement(
+            cluster_ref,
+            args.enable_kernel_module_signature_enforcement,
+        )
+      except apitools_exceptions.HttpError as error:
+        raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
     else:
       if args.enable_legacy_authorization is not None:
         op_ref = adapter.SetLegacyAuthorization(
@@ -1124,6 +1150,7 @@ class UpdateBeta(Update):
     flags.AddAutoMonitoringScopeFlags(
         group_logging_monitoring_config, hidden=False
     )
+    flags.AddManagedOTelScopeFlags(group_logging_monitoring_config, hidden=True)
     flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddEnableLoggingMonitoringSystemOnlyFlag(group)
     flags.AddEnableWorkloadMonitoringEapFlag(group)
@@ -1140,7 +1167,7 @@ class UpdateBeta(Update):
     flags.AddRecurringMaintenanceWindowFlags(group, is_update=True)
     flags.AddPodSecurityPolicyFlag(group)
     flags.AddBinauthzFlags(group, release_track=base.ReleaseTrack.BETA)
-    flags.AddAutoprovisioningFlags(group)
+    flags.AddAutoprovisioningFlags(group, napless=True)
     flags.AddAutoscalingProfilesFlag(group)
     flags.AddVerticalPodAutoscalingFlags(group, experimental=True)
     flags.AddResourceUsageExportFlags(group, is_update=True)
@@ -1249,6 +1276,11 @@ class UpdateBeta(Update):
     flags.AddMembershipTypeFlags(group_fleet_flags, is_update=True)
     flags.AddNetworkTierFlag(group)
     flags.AddControlPlaneEgressFlag(group)
+    flags.AddAutopilotPrivilegedAdmissionFlag(group, hidden=True)
+    flags.AddPodSnapshotConfigFlags(group, hidden=True)
+    flags.AddEnableKernelModuleSignatureEnforcementFlag(
+        group, for_node_pool=True, hidden=True
+    )
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -1459,6 +1491,13 @@ class UpdateBeta(Update):
     opts.enable_default_compute_class = args.enable_default_compute_class
     opts.network_tier = args.network_tier
     opts.control_plane_egress_mode = args.control_plane_egress
+    opts.managed_otel_scope = args.managed_otel_scope
+    opts.autopilot_privileged_admission = (
+        args.autopilot_privileged_admission
+    )
+    opts.enable_kernel_module_signature_enforcement = (
+        args.enable_kernel_module_signature_enforcement
+    )
     return opts
 
 
@@ -1485,6 +1524,7 @@ class UpdateAlpha(Update):
     flags.AddAutoMonitoringScopeFlags(
         group_logging_monitoring_config, hidden=False
     )
+    flags.AddManagedOTelScopeFlags(group_logging_monitoring_config, hidden=True)
     flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddEnableLoggingMonitoringSystemOnlyFlag(group)
     flags.AddEnableWorkloadMonitoringEapFlag(group)
@@ -1497,7 +1537,7 @@ class UpdateAlpha(Update):
     flags.AddUpdateLabelsFlag(group)
     flags.AddRemoveLabelsFlag(group)
     flags.AddNetworkPolicyFlags(group)
-    flags.AddAutoprovisioningFlags(group, hidden=False)
+    flags.AddAutoprovisioningFlags(group, hidden=False, napless=True)
     flags.AddAutoscalingProfilesFlag(group)
     flags.AddDailyMaintenanceWindowFlag(group, add_unset_text=True)
     flags.AddRecurringMaintenanceWindowFlags(group, is_update=True)
@@ -1611,6 +1651,11 @@ class UpdateAlpha(Update):
     flags.AddMembershipTypeFlags(group_fleet_flags, is_update=True)
     flags.AddNetworkTierFlag(group)
     flags.AddControlPlaneEgressFlag(group)
+    flags.AddAutopilotPrivilegedAdmissionFlag(group, hidden=True)
+    flags.AddPodSnapshotConfigFlags(group, hidden=True)
+    flags.AddEnableKernelModuleSignatureEnforcementFlag(
+        group, for_node_pool=True, hidden=True
+    )
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -1817,4 +1862,11 @@ class UpdateAlpha(Update):
     opts.enable_default_compute_class = args.enable_default_compute_class
     opts.network_tier = args.network_tier
     opts.control_plane_egress_mode = args.control_plane_egress
+    opts.managed_otel_scope = args.managed_otel_scope
+    opts.autopilot_privileged_admission = (
+        args.autopilot_privileged_admission
+    )
+    opts.enable_kernel_module_signature_enforcement = (
+        args.enable_kernel_module_signature_enforcement
+    )
     return opts
